@@ -9,7 +9,7 @@
 #'
 #' @importFrom igraph as.igraph
 #' @describeIn as.igraph Convert `mgNetwork` objects to `igraph` objects.
-#' @export 
+#' @export
 as.igraph.mgNetwork <- function(x, ...) {
     # Simple test to know if the graph is directed or undirected
     directed <- ifelse(all(x$interactions$direction == "directed"), TRUE, FALSE)
@@ -18,13 +18,14 @@ as.igraph.mgNetwork <- function(x, ...) {
     # drop geometry
     x$interactions <- x$interactions[, names(x$interactions) != "geom"]
     nm <- c("node_from", "node_to")
-    x$interactions <- x$interactions[, c(nm, names(x$interactions)[! names(x$interactions) %in% nm])]
+    x$interactions <- x$interactions[,
+      c(nm, names(x$interactions)[! names(x$interactions) %in% nm])]
     igraph::graph_from_data_frame(d = x$interactions, directed = directed,
       vertices = x$nodes)
 }
 
-
-#' @describeIn as.igraph Convert `mgNetworksCollection` objects to a list of `igraph` objects.
+#' @describeIn as.igraph
+#' Convert `mgNetworksCollection` objects to a list of `igraph` objects.
 #' @export
 as.igraph.mgNetworksCollection <- function(x, ...) {
     lapply(x, as.igraph.mgNetwork)
